// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos.Basics
{
    // PDF 仕様には、常に利用可能な 14 の標準フォントが記載されています。
    // DsPdf にはこれらのフォントが組み込まれており、このサンプルが示すように直接使用することができます。
    public class StandardPdfFonts
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            // テキストの挿入位置（デフォルト解像度は 72 dpi、1 インチの余白を使用）。
            const float margin = 72;
            var ip = new PointF(margin, margin);
            var tf = new TextFormat() { FontSize = 12 };
            Action<string, GCTEXT.Font> drawText = (tag_, fnt_) =>
            {
                tf.Font = fnt_;
                string tstr = $"{tag_} ({fnt_.FullFontName}): DioDocs for PDF 日本語テキスト";
                var s = g.MeasureString(tstr, tf, doc.PageSize.Width - margin * 2);
                g.DrawString(tstr, tf, new RectangleF(ip, s));
                ip.Y += s.Height * 1.5f;
            };
            // 14 種類の標準フォントのサンプルを描画します。
            drawText("Helvetica", StandardFonts.Helvetica);
            drawText("HelveticaItalic", StandardFonts.HelveticaItalic);
            drawText("HelveticaBold", StandardFonts.HelveticaBold);
            drawText("HelveticaBoldItalic", StandardFonts.HelveticaBoldItalic);
            drawText("Times", StandardFonts.Times);
            drawText("TimesItalic", StandardFonts.TimesItalic);
            drawText("TimesBold", StandardFonts.TimesBold);
            drawText("TimesBoldItalic", StandardFonts.TimesBoldItalic);
            drawText("Courier", StandardFonts.Courier);
            drawText("CourierItalic", StandardFonts.CourierItalic);
            drawText("CourierBold", StandardFonts.CourierBold);
            drawText("CourierBoldItalic", StandardFonts.CourierBoldItalic);
            drawText("Symbol", StandardFonts.Symbol);
            drawText("ZapfDingbats", StandardFonts.ZapfDingbats);
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
